'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-15d2a36c.js');
const dateutils = require('./dateutils-523a8ee7.js');
const utils = require('./utils-aa13c8b6.js');

const K2btCalendarFullView = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.newDraftCreated = index.createEvent(this, "newDraftCreated", 7);
    this.draftCancelled = index.createEvent(this, "draftCancelled", 7);
    this.itemClicked = index.createEvent(this, "itemClicked", 7);
    this.fetchAppointmentsForPeriod = index.createEvent(this, "fetchAppointmentsForPeriod", 7);
    this.showheader = true;
    this.showcalendarnavigation = true;
    this.showperiodnavigation = true;
    this.showviewselection = true;
    this.showcalendarselection = true;
    this.starthour = 8;
    this.endhour = 20;
    this.readonly = true;
    this.todaycaption = 'Today';
    this.daycaption = 'Day';
    this.weekcaption = 'Week';
    this.workweekcaption = 'Work Week';
    this.monthcaption = 'Month';
    this.yearcaption = 'Year';
    this.seemorecaption = 'See more';
    this.itemsperdayinmonthview = 5;
    this.dayviewenabled = true;
    this.weekviewenabled = true;
    this.workweekviewenabled = true;
    this.monthviewenabled = true;
    this.weekstartday = dateutils.WeekStartDay.Sunday;
    this.calendars = [];
    this.selectedCalendars = null;
    this.advancedSelectorOpen = false;
  }
  setPeriodAppointments(parm) {
    if (this.selectedCalendars == null) {
      this.selectedCalendars = parm.calendars.map(c => c.id);
    }
    this.clearAppointmentsInRange(parm.dateFrom, parm.dateTo);
    this.pruneFarawayItems(parm.dateFrom, parm.dateTo);
    this.mergeCalendars(parm.calendars);
    this.assignCalendarMissingClasses(this.calendars);
    this.calendars = [].concat(this.calendars);
  }
  pruneFarawayItems(dateFrom, dateTo) {
    for (let calendar of this.calendars) {
      if (calendar.items.length > K2btCalendarFullView.MAX_STORED_ITEMS) {
        calendar.items.sort((i1, i2) => this.getDistance(i1, dateFrom, dateTo) - this.getDistance(i2, dateFrom, dateTo));
        calendar.items = calendar.items.slice(0, K2btCalendarFullView.MAX_STORED_ITEMS);
      }
    }
  }
  // Item is assumed to be outside range, only check relevant bounds
  getDistance(i, dateFrom, dateTo) {
    return Math.min(Math.abs(i.dateTo.getTime() - dateFrom.getTime()), Math.abs(i.dateFrom.getTime() - dateTo.getTime()));
  }
  assignCalendarMissingClasses(calendars) {
    for (var i = 0; i < calendars.length; i++) {
      if (!calendars[i].class)
        calendars[i].class = 'K2BT_Calendar' + i;
    }
  }
  mergeCalendars(appointments) {
    for (let calendar of appointments) {
      var filteredCalendars = this.calendars.filter(c => c.id == calendar.id);
      if (filteredCalendars.length > 0) {
        filteredCalendars[0].items = filteredCalendars[0].items.concat(calendar.items);
      }
      else {
        this.calendars.push(calendar);
      }
    }
  }
  // dateFrom and dateTo should be treated as local date only values (no time)
  clearAppointmentsInRange(dateFrom, dateTo) {
    var lowerBound = dateFrom;
    var upperBound = dateTo;
    this.calendars = this.calendars.map(c => {
      return {
        id: c.id,
        description: c.description,
        class: c.class,
        items: c.items.filter(i => !dateutils.DateUtils.datePeriodInBound(lowerBound, upperBound, dateutils.DateUtils.getDateAtMidnight(i.dateFrom), dateutils.DateUtils.getDateAtMidnight(i.dateTo))),
      };
    });
  }
  componentWillLoad() {
    this.currentview = dateutils.CalendarPeriodView.Week;
    this.goToToday();
  }
  render() {
    return (index.h("div", { class: "K2BT_CalendarContainer" }, this.getHeader(), index.h("div", { class: "K2BT_CalendarFullViewContent" }, this.getCalendarFullViewContent())));
  }
  getHeader() {
    return this.showheader ? (index.h("div", { class: "K2BT_CalendarFullViewHeader" }, this.getTodayButton(), this.getPreviousNextButtons(), this.getContextTitle(), this.getCalendarSelectionCombobox(), this.getPeriodSelectionCombobox())) : ('');
  }
  getCalendarFullViewContent() {
    switch (this.currentview) {
      case dateutils.CalendarPeriodView.Day:
        return (index.h("k2bt-calendar-day-view", { year: this.dateFrom.getFullYear(), month: this.dateFrom.getMonth(), day: this.dateFrom.getDate(), startHour: this.starthour, endHour: this.endhour, readonly: this.readonly, calendars: this.filterSelectedCalendars(this.calendars), showhours: true, alldayrows: 0, ref: c => (this.dayView = c) }));
      case dateutils.CalendarPeriodView.Week:
      case dateutils.CalendarPeriodView.WorkWeek:
        return (index.h("k2bt-calendar-period-view", { dateFrom: this.dateFrom, dateTo: this.dateTo, startHour: this.starthour, endHour: this.endhour, readonly: this.readonly, calendars: this.filterSelectedCalendars(this.calendars), ref: c => (this.weekView = c) }));
      case dateutils.CalendarPeriodView.Month:
        return (index.h("k2bt-calendar-month-view", { year: this.dateFrom.getFullYear(), month: this.dateFrom.getMonth() + 1, readonly: this.readonly, calendars: this.filterSelectedCalendars(this.calendars), seemorecaption: this.seemorecaption, itemsperday: this.itemsperdayinmonthview, weekstartday: this.weekstartday,
          //@ts-ignore
          onDayClicked: ev => this.dayClicked(ev.detail.date), ref: c => (this.monthView = c) }));
    }
  }
  filterSelectedCalendars(calendars) {
    return calendars.filter(c => this.selectedCalendars.indexOf(c.id) !== -1);
  }
  calendarSelectionChanged() {
    this.selectedCalendars = this.calendarCombo.value;
  }
  getCalendarSelectionCombobox() {
    if (this.showcalendarselection) {
      var values = this.getAvailableCalendars();
      if (values.length > 1) {
        return (index.h("div", { class: "K2BT_CalendarCalendarSelectionCombobox" }, index.h("k2bt-enhancedcombo", { onChange: () => this.calendarSelectionChanged(), includesearch: false, showselectionastags: false, enableadditem: false, includeemptyitem: false, headermaxvisibleitems: 1, values: values, value: this.selectedCalendars, maxSelectionSize: 0, ref: c => (this.calendarCombo = c) })));
      }
    }
    return '';
  }
  getAvailableCalendars() {
    return this.calendars.map(c => {
      return { value: c.id, description: c.description, badgeClass: c.class };
    });
  }
  getPeriodSelectionCombobox() {
    if (this.showviewselection) {
      var values = this.getAvailableContentViews();
      if (values.length > 1) {
        var value = [this.currentview];
        return (index.h("div", { class: "K2BT_CalendarPeriodSelectionCombobox" }, index.h("k2bt-enhancedcombo", { onChange: this.periodSelectionChanged.bind(this), includesearch: false, enableadditem: false, includeemptyitem: false, values: values, value: value, ref: c => (this.periodCombo = c) })));
      }
    }
    return '';
  }
  getAvailableContentViews() {
    var values = [];
    if (this.dayviewenabled)
      values.push({
        value: dateutils.CalendarPeriodView.Day,
        description: this.daycaption,
      });
    if (this.weekviewenabled)
      values.push({
        value: dateutils.CalendarPeriodView.Week,
        description: this.weekcaption,
      });
    if (this.workweekviewenabled)
      values.push({
        value: dateutils.CalendarPeriodView.WorkWeek,
        description: this.workweekcaption,
      });
    if (this.monthviewenabled)
      values.push({
        value: dateutils.CalendarPeriodView.Month,
        description: this.monthcaption,
      });
    return values;
  }
  getContextTitle() {
    return index.h("div", { class: "K2BT_CalendarHeaderTitle" }, dateutils.DateUtils.getMonthName(this.dateFrom.getMonth()) + ' ' + this.dateFrom.getFullYear());
  }
  periodSelectionChanged() {
    this.switchView(dateutils.CalendarPeriodView[utils.EnumUtils.getEnumKeyByEnumValue(dateutils.CalendarPeriodView, this.periodCombo.value[0])]);
  }
  switchView(view) {
    this.currentview = view;
    this.goToDate(this.dateFrom);
  }
  cancelDraft() {
    var _a;
    (_a = this.dayView) === null || _a === void 0 ? void 0 : _a.cancelDraft();
    if (this.weekView)
      this.weekView.cancelDraft();
  }
  getPreviousNextButtons() {
    return this.showperiodnavigation ? (index.h("div", { class: "K2BT_CalendarPeriodButtons" }, index.h("div", { class: "K2BT_CalendarPreviousPeriodButton", onClick: this.goToPreviousPeriod.bind(this) }), index.h("div", { class: "K2BT_CalendarNextPeriodButton", onClick: this.goToNextPeriod.bind(this) }))) : ('');
  }
  goToNextPeriod() {
    var d = new Date(this.dateFrom.getTime());
    switch (this.currentview) {
      case dateutils.CalendarPeriodView.Day:
        d.setDate(d.getDate() + 1);
        break;
      case dateutils.CalendarPeriodView.Week:
      case dateutils.CalendarPeriodView.WorkWeek:
        d.setDate(d.getDate() + 7);
        break;
      case dateutils.CalendarPeriodView.Month:
        d = new Date(d.getFullYear(), d.getMonth() + 1, 1);
        break;
    }
    this.goToDate(d);
  }
  goToPreviousPeriod() {
    var d = new Date(this.dateFrom.getTime());
    switch (this.currentview) {
      case dateutils.CalendarPeriodView.Day:
        d.setDate(d.getDate() - 1);
        break;
      case dateutils.CalendarPeriodView.Week:
      case dateutils.CalendarPeriodView.WorkWeek:
        d.setDate(d.getDate() - 7);
        break;
      case dateutils.CalendarPeriodView.Month:
        d = new Date(d.getFullYear(), d.getMonth() - 1, 1);
        break;
    }
    this.goToDate(d);
  }
  closeMenu(ev) {
    if (this.advancedSelectorOpen && this.quickDaySelectorContainer && !this.quickDaySelectorContainer.contains(ev.target))
      this.advancedSelectorOpen = false;
  }
  getTodayButton() {
    return this.showcalendarnavigation ? (index.h("div", { class: "K2B_CalendarQuickDaySelectorContainer", ref: c => (this.quickDaySelectorContainer = c) }, index.h("div", { class: "K2B_CalendarQuickDaySelector" }, index.h("div", { class: "K2BT_CalendarTodayButton", onClick: this.goToToday.bind(this) }, this.todaycaption), index.h("div", { class: "K2BT_CalendarAdvancedSelectorToggle", onClick: () => (this.advancedSelectorOpen = !this.advancedSelectorOpen) })), this.getAdvancedSelectorContents())) : ('');
  }
  getAdvancedSelectorContents() {
    return this.advancedSelectorOpen ? (index.h("div", { class: "K2BT_CalendarAdvancedSelectorContents" }, index.h("k2bt-calendar-day-in-month-picker", { selectedDate: this.dateFrom, weekstartday: this.weekstartday, onDayClicked: e => {
        this.advancedSelectorOpen = false;
        this.goToDate(e.detail);
      } }))) : ('');
  }
  dayClicked(d) {
    if (this.dayviewenabled) {
      this.switchView(dateutils.CalendarPeriodView.Day);
      this.goToDate(d);
    }
  }
  goToToday() {
    this.goToDate(new Date());
  }
  goToDate(date) {
    var originalDateFrom = this.dateFrom ? new Date(this.dateFrom.getTime()) : null;
    var originalDateTo = this.dateTo ? new Date(this.dateTo.getTime()) : null;
    switch (this.currentview) {
      case dateutils.CalendarPeriodView.Day:
        this.dateFrom = date;
        this.dateTo = date;
        break;
      case dateutils.CalendarPeriodView.Week:
        var d = new Date(date.getTime());
        if (this.weekstartday === dateutils.WeekStartDay.Sunday) {
          d.setDate(d.getDate() - d.getDay());
        }
        else {
          d.setDate(d.getDate() - d.getDay() + 1);
        }
        this.dateFrom = d;
        d = new Date(date.getTime());
        if (this.weekstartday === dateutils.WeekStartDay.Sunday) {
          d.setDate(d.getDate() - d.getDay() + 7);
        }
        else {
          d.setDate(d.getDate() - d.getDay() + 8);
        }
        this.dateTo = d;
        break;
      case dateutils.CalendarPeriodView.WorkWeek:
        d = new Date(date.getTime());
        d.setDate(d.getDate() - d.getDay() + 1);
        this.dateFrom = d;
        d = new Date(date.getTime());
        d.setDate(d.getDate() - d.getDay() + 6);
        this.dateTo = d;
        break;
      case dateutils.CalendarPeriodView.Month:
        this.dateFrom = new Date(date.getFullYear(), date.getMonth(), 1);
        this.dateTo = new Date(date.getFullYear(), date.getMonth() + 1, 0);
        break;
    }
    if (originalDateFrom != this.dateFrom || originalDateTo != this.dateTo) {
      this.fetchAppointmentsForPeriod.emit({
        dateFrom: this.dateFrom,
        dateTo: this.dateTo,
      });
    }
  }
};
K2btCalendarFullView.MAX_STORED_ITEMS = 300;

exports.k2bt_calendar_full_view = K2btCalendarFullView;
