'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-15d2a36c.js');
const utils = require('./utils-aa13c8b6.js');

const k2btToggleBarCss = ":host{display:block}";

const K2btToggleBar = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.selectionErrorEvent = index.createEvent(this, "selectionError", 7);
    this.inputEvent = index.createEvent(this, "input", 7);
    this.changeEvent = index.createEvent(this, "change", 7);
    this.newRecordClickedEvent = index.createEvent(this, "newRecordClicked", 7);
    this.SmallChip = 'SmallChip';
    this.MediumChip = 'MediumChip';
    this.Rectangle = 'Rectangle';
    this.value = null;
    this.values = [];
    this.includeemptyitem = true;
    this.emptyitemtext = '(none)';
    this.noresultsfoundtext = 'No results found';
    this.enableadditem = true;
    this.additemcaption = 'New record';
    this.enabled = true;
    this.readonlyclass = '';
    this.togglestyle = this.MediumChip;
    this.maxSelectionSize = 1;
    this.selectedElement = null;
  }
  onImageError(e) {
    e.target.classList.add('K2BT_ToggleBarIconInvisible');
  }
  isCollection() {
    return this.maxSelectionSize != 1;
  }
  selectionIsFull() {
    return this.isCollection() && this.maxSelectionSize != 0 && this.maxSelectionSize <= this.value.length;
  }
  itemIsSelected(item) {
    var _a, _b;
    return ((_b = (_a = this.value) === null || _a === void 0 ? void 0 : _a.filter(selectedItem => selectedItem.toString().trim() == item.value.trim()).length) !== null && _b !== void 0 ? _b : 0) > 0;
  }
  setValue(value) {
    var _a, _b, _c;
    if (this.maxSelectionSize == 1) {
      this.value = [value];
    }
    else {
      if (((_b = (_a = this.value) === null || _a === void 0 ? void 0 : _a.filter(v => v.trim() === value.trim()).length) !== null && _b !== void 0 ? _b : 0) === 0) {
        if (!this.selectionIsFull())
          this.value = ((_c = this.value) !== null && _c !== void 0 ? _c : []).concat([value]);
        else {
          this.errorCode = K2btToggleBar.ERROR_SELECTION_FULL;
          this.selectionErrorEvent.emit({});
        }
      }
      else
        this.value = this.value.filter(v => v.trim() !== value.trim());
    }
    this.inputEvent.emit();
    this.changeEvent.emit(value);
  }
  getToggleContent(values, containsDetails, containsIcons, containsTrailingText) {
    if (values.length == 0) {
      return (index.h("div", { class: "K2BT_ToggleBar_NoItems", style: !this.enabled ? { display: 'none' } : {} }, this.noresultsfoundtext));
    }
    else {
      const atomic = values.filter(v => { var _a, _b; return ((_b = (_a = v.items) === null || _a === void 0 ? void 0 : _a.length) !== null && _b !== void 0 ? _b : 0) == 0; });
      const currentLevelCategories = values.filter(v => { var _a; return ((_a = v.items) === null || _a === void 0 ? void 0 : _a.length) > 0; });
      var containerClasses = this.GetContainerClasses();
      return (index.h("div", { class: containerClasses, style: !this.enabled ? { display: 'none' } : {} }, atomic.length > 0 ? (index.h("div", { class: "K2BT_ToggleBarItemContainer" }, atomic.map(item => this.getItemContent(item, containsIcons, containsTrailingText, containsDetails)))) : (''), currentLevelCategories.map(c => {
        return (index.h("div", { class: "K2BT_ToggleBar_CategoryContainer" }, index.h("div", { class: "K2BT_ToggleBarCategoryName" }, c.description), this.getToggleContent(c.items, containsDetails, containsIcons, containsTrailingText)));
      })));
    }
  }
  getItemContent(item, containsIcons, containsTrailingText, containsDetails) {
    return (index.h("div", { class: this.itemIsSelected(item) ? 'K2BT_ToggleBarItem K2BT_ToggleBarItemSelected' : 'K2BT_ToggleBarItem', ref: c => {
        if (this.itemIsSelected(item))
          this.selectedElement = c;
      }, onClick: () => this.setValue(item.value.trim()) }, this.getIconHTMLIfNecessary(containsIcons, item), index.h("div", { class: "K2BT_ToggleBarItem_TextSection" }, index.h("div", { class: "K2BT_ToggleBarItem_TextContainer" }, index.h("span", { class: "K2BT_ToggleBarDescription" }, item.description), containsTrailingText ? index.h("span", { class: "K2BT_ToggleBarTrailingText" }, item.trailingText) : ''), index.h("div", { class: "K2BT_ToggleBarItem_TextContainer" }, containsDetails ? index.h("span", { class: "K2BT_ToggleBarSubtitle" }, item.detail) : ''))));
  }
  getIconHTMLIfNecessary(containsIcons, item) {
    return containsIcons ? (index.h("div", { class: "K2BT_ToggleBarIconContainer" }, index.h("img", { class: "K2BT_ToggleBarIcon", src: item.imageUrl, onError: e => this.onImageError(e) }))) : ('');
  }
  GetContainerClasses() {
    var containerClasses = 'K2BT_ToggleBar_Container';
    if (this.togglestyle == this.SmallChip) {
      containerClasses += ' K2BT_ToggleBarSmallChip';
    }
    else if (this.togglestyle == this.Rectangle) {
      containerClasses += ' K2BT_ToggleBarRectangle';
    }
    return containerClasses;
  }
  getSelectedItemsContent() {
    if (this.value == null)
      return this.emptyitemtext;
    else {
      var vals = utils.ControlInfoValue.getAtomicValues_impl(this.values).filter(value => this.itemIsSelected(value));
      if (vals.length > 0)
        return vals.map(v => v.description).join(', ');
      else
        return this.emptyitemtext;
    }
  }
  render() {
    var containsDetails = utils.ControlInfoValue.containsDetails(utils.ControlInfoValue.getAtomicValues_impl(this.values));
    var containsIcons = utils.ControlInfoValue.containsIcons(utils.ControlInfoValue.getAtomicValues_impl(this.values));
    var containsTrailingText = utils.ControlInfoValue.containsTrailingText(utils.ControlInfoValue.getAtomicValues_impl(this.values));
    var valueList = this.getValues();
    return (index.h(index.Host, null, index.h("p", { class: "form-control-static", style: this.enabled ? { display: 'none' } : {} }, index.h("span", { class: !this.enabled ? this.readonlyclass : this.readonlyclass + ' gx-invisible', "data-gx-readonly": "" }, this.getSelectedItemsContent())), this.getToggleContent(valueList, containsDetails, containsIcons, containsTrailingText)));
  }
  getValues() {
    var valueList = [...this.values];
    if (this.includeemptyitem && !this.isCollection()) {
      valueList.unshift({
        value: '',
        description: this.emptyitemtext,
        imageUrl: '',
        detail: '',
        trailingText: '',
        badgeClass: '',
        items: [],
        tooltip: ''
      });
    }
    return valueList;
  }
  componentDidLoad() {
    var currentValues = utils.ControlInfoValue.getAtomicValues_impl(this.values);
    if (!this.includeemptyitem && currentValues.filter(v => this.itemIsSelected(v)).length == 0) {
      if (currentValues.length > 0) {
        this.setValue(currentValues[0].value.trim());
      }
    }
  }
};
K2btToggleBar.ERROR_SELECTION_FULL = 'SELECTION_FULL';
K2btToggleBar.style = k2btToggleBarCss;

exports.k2bt_toggle_bar = K2btToggleBar;
