import { r as registerInstance, h } from './index-996ea621.js';

class MultiLevelMenu {
}
MultiLevelMenu.HINT_GROUP = 'group';
MultiLevelMenu.HINT_COLLAPSIBLE = 'collapsible';
MultiLevelMenu.HINT_GROUPWITHOUTTITLE = 'groupwithouttitle';

const k2btMegaMenuCss = ":host{display:block}";

const K2btMegaMenu = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.items = [];
    this.openSublevels = [];
    this.timeout = null;
  }
  onAtomicItemClick(i) {
    console.log('Item clicked: ' + i.Code);
  }
  onSubLevelClick(i) {
    if (this.openSublevels.indexOf(i.Code) != -1)
      this.openSublevels = this.openSublevels.filter(c => c != i.Code);
    else
      this.openSublevels = [...this.openSublevels, i.Code];
  }
  render() {
    return (h("div", { class: "K2BT_MegaMenuContainer" }, h("div", { class: "K2BT_MegaMenuHeader" }, this.items.map(i => this.renderFirstLevelItem(i))), h("div", { class: "K2BT_MegaMenuContents" }, this.getMegaMenuContents())));
  }
  getMegaMenuContents() {
    return this.items
      .filter(i => { var _a; return ((_a = i.Items) === null || _a === void 0 ? void 0 : _a.length) > 0; })
      .map(i => {
      var classes = 'K2BT_MegaMenuFirstLevelSublevelContents';
      if (this.activeSublevelCode === i.Code)
        classes += ' K2BT_MegaMenuFirstLevelSublevelContentsOpen';
      var subLevels = i.Items.filter(it => { var _a; return ((_a = it.Items) === null || _a === void 0 ? void 0 : _a.length) > 0; });
      return (h("div", { class: classes, onMouseEnter: () => this.onFirstLevelMouseEnter(i.Code), onMouseLeave: () => this.onFirstLevelMouseLeave() }, subLevels.length > 0
        ? i.Items.map(it => this.renderSecondLevelItem(it))
        : //@ts-ignore
          this.renderSecondLevelSublevel({
            Items: i.Items,
          })));
    });
  }
  renderFirstLevelItem(i) {
    var _a;
    if (((_a = i.Items) === null || _a === void 0 ? void 0 : _a.length) > 0)
      return this.renderFirstLevelSublevel(i);
    else
      return this.renderFirstLevelAtomicItem(i);
  }
  renderFirstLevelAtomicItem(i) {
    return (h("div", { class: "K2BT_MegaMenuFirstLevelItem", onClick: () => this.onAtomicItemClick(i) }, h("a", { href: i.Link }, this.getItemIconAndTitle(i))));
  }
  renderFirstLevelSublevel(i) {
    var classes = 'K2BT_MegaMenuFirstLevelSublevel';
    if (this.activeSublevelCode === i.Code)
      classes += ' K2BT_MegaMenuFirstLevelSublevelOpen';
    return (h("div", { class: classes, onClick: () => this.onSubLevelClick(i), onMouseEnter: () => this.onFirstLevelMouseEnter(i.Code), onMouseLeave: () => this.onFirstLevelMouseLeave() }, h("div", { class: "K2BT_MegaMenuFirstLevelSublevelHeader" }, this.getItemIconAndTitle(i))));
  }
  getItemIconAndTitle(i) {
    return (h("div", null, i.ImageClass ? h("span", { class: 'K2BT_MegaMenuIcon ' + i.ImageClass }) : '', h("span", { class: "K2BT_MegaMenuTitle" }, i.Title)));
  }
  onFirstLevelMouseEnter(code) {
    if (this.activeSublevelCode != code) {
      this.activeSublevelCode = code;
    }
    if (this.timeout) {
      clearTimeout(this.timeout);
      this.timeout = null;
    }
  }
  onFirstLevelMouseLeave() {
    this.timeout = setTimeout((() => {
      this.activeSublevelCode = '';
    }).bind(this), 500);
  }
  renderSecondLevelItem(i) {
    var _a;
    if (((_a = i.Items) === null || _a === void 0 ? void 0 : _a.length) > 0)
      return this.renderSecondLevelSublevel(i);
    else
      return this.renderSecondLevelAtomicItem(i);
  }
  renderSecondLevelAtomicItem(i) {
    return (h("div", { class: "K2BT_MegaMenuSecondLevelItem", onClick: () => this.onAtomicItemClick(i) }, h("a", { href: i.Link }, this.getItemIconAndTitle(i))));
  }
  renderSecondLevelSublevel(i) {
    if (i.ShowAs != MultiLevelMenu.HINT_GROUPWITHOUTTITLE) {
      return (h("div", { class: "K2BT_MegaMenuSecondLevelSublevel", onClick: () => this.onSubLevelClick(i) }, i.Title ? h("div", { class: "K2BT_MegaMenuSecondLevelSublevelHeader" }, this.getItemIconAndTitle(i)) : '', h("div", { class: "K2BT_MegaMenuSecondLevelSublevelContents" }, i.Items.map(it => this.renderInnerLevelItem(it)))));
    }
    else {
      return (h("div", { class: "K2BT_MegaMenuSecondLevelSublevel K2BT_MegaMenuSecondLevelSublevelNoTitle", onClick: () => this.onSubLevelClick(i) }, h("div", { class: "K2BT_MegaMenuSecondLevelSublevelContents" }, i.Items.map(it => this.renderSecondLevelSublevel(it)))));
    }
  }
  renderInnerLevelItem(i) {
    var _a;
    if (((_a = i.Items) === null || _a === void 0 ? void 0 : _a.length) > 0)
      return this.renderInnerLevelSublevel(i);
    else
      return this.renderInnerLevelAtomicItem(i);
  }
  renderInnerLevelAtomicItem(i) {
    return (h("div", { class: "K2BT_MegaMenuInnerLevelItem", onClick: () => this.onAtomicItemClick(i) }, h("a", { href: i.Link }, this.getItemIconAndTitle(i))));
  }
  renderInnerLevelSublevel(i) {
    const isCollapsible = i.ShowAs === MultiLevelMenu.HINT_COLLAPSIBLE || i.ShowAs === '';
    var classes = ['K2BT_MegaMenuInnerLevelSublevel'];
    if (isCollapsible)
      classes.push('K2BT_MegaMenuInnerLevelSublevelCollapsible');
    if (this.openSublevels.indexOf(i.Code) !== -1)
      classes.push('K2BT_MegaMenuInnerLevelSublevelOpen');
    return (h("div", { class: classes.join(' '), onClick: () => {
        if (isCollapsible)
          this.onSubLevelClick(i);
      } }, h("div", { class: "K2BT_MegaMenuInnerLevelSublevelHeader" }, this.getItemIconAndTitle(i)), h("div", { class: "K2BT_MegaMenuInnerLevelSublevelContents" }, i.Items.map(it => this.renderInnerLevelItem(it)))));
  }
};
K2btMegaMenu.style = k2btMegaMenuCss;

export { K2btMegaMenu as k2bt_mega_menu };
